access

package
v0.0.0-...-935195a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0, MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

const (
	InvalidAccessConfirmSubjectErrorName = "InvalidAccessConfirmSubject"
	InvalidAccessConfirmIssuerErrorName  = "InvalidAccessConfirmIssuer"
)
const (
	DelegationNotFoundErrorName  = "DelegationNotFound"
	InsufficientStorageErrorName = "InsufficientStorage"
)
const (
	InvalidAuthorizationAccountErrorName  = "InvalidAuthorizationAccount"
	InvalidAuthorizationAudienceErrorName = "InvalidAuthorizationAudience"
)
const ClaimCommand = "/access/claim"
const ConfirmCommand = "/access/confirm"
const ConfirmMetaKey = "accessConfirm"

ConfirmMetaKey is the key in metadata in any delegation created by a successful access request. The value is a link back to the `/access/confirm` invocation.

const DelegateCommand = "/access/delegate"
const RequestCommand = "/access/request"
const RequestMetaKey = "accessRequest"

RequestFactKey is the key in metadata in any delegation created by a successful access request. The value is a link back to the `/access/request` invocation.

Variables

var (
	ErrInvalidAccessConfirmSubject = errors.New(InvalidAccessConfirmSubjectErrorName, "the subject of an access confirm invocation must be the service itself")
	ErrInvalidAccessConfirmIssuer  = errors.New(InvalidAccessConfirmIssuerErrorName, "the issuer of an access confirm invocation must be a valid mailto DID")
)

Claim can be invoked by an agent to claim a set of delegations from the account.

Confirm can be invoked by an agent to confirm an access request.

Delegate can be invoked by an agent to delegate a set of capabilities that may be subsequently claimed by another agent.

Request can be invoked by an agent to request set of capabilities from the account.

Functions

This section is empty.

Types

type CapabilityRequest

type CapabilityRequest = adm.CapabilityRequestModel

type ClaimArguments

type ClaimArguments = cdm.UnitModel

type ClaimOK

type ClaimOK = adm.ClaimOKModel

type ConfirmArguments

type ConfirmArguments = adm.ConfirmArgumentsModel

type ConfirmOK

type ConfirmOK = adm.ConfirmOKModel

type DelegateArguments

type DelegateArguments = adm.DelegateArgumentsModel

type DelegateOK

type DelegateOK = cdm.UnitModel

type RequestArguments

type RequestArguments = adm.RequestArgumentsModel

type RequestOK

type RequestOK = adm.RequestOKModel

Directories

Path Synopsis
gen command

Jump to