assert

package
v0.0.0-...-935195a Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0, MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

const EqualsCommand = "/assert/equals"
const IndexCommand = "/assert/index"
const LocationCommand = "/assert/location"

Variables

Equals claims data is referred to by another CID e.g CAR CID & Piece CID

Index claims that a content graph can be found in blob(s) that are identified and indexed in the given index CID.

Functions

This section is empty.

Types

type EqualsArguments

type EqualsArguments = adm.EqualsArgumentsModel

type EqualsOK

type EqualsOK = cdm.UnitModel

type IndexArguments

type IndexArguments = adm.IndexArgumentsModel

type IndexOK

type IndexOK = cdm.UnitModel

type LocationArguments

type LocationArguments = adm.LocationArgumentsModel

type LocationOK

type LocationOK = cdm.UnitModel

type Range

type Range = adm.RangeModel

Directories

Path Synopsis
gen command

Jump to