Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BlobIndexModel ¶
type BlobIndexModel struct {
Digest multihash.Multihash
Slices []BlobSliceModel
}
BlobIndexModel is the golang structure for encoding a shard of CIDs in a block
func (*BlobIndexModel) MarshalCBOR ¶
func (t *BlobIndexModel) MarshalCBOR(w io.Writer) error
func (*BlobIndexModel) MarshalDagJSON ¶
func (t *BlobIndexModel) MarshalDagJSON(w io.Writer) error
func (*BlobIndexModel) UnmarshalCBOR ¶
func (t *BlobIndexModel) UnmarshalCBOR(r io.Reader) (err error)
func (*BlobIndexModel) UnmarshalDagJSON ¶
func (t *BlobIndexModel) UnmarshalDagJSON(r io.Reader) (err error)
type BlobSliceModel ¶
type BlobSliceModel struct {
Digest multihash.Multihash
Range RangeModel
}
BlobSliceModel describes a multihash and its byte offset in a blob
func (*BlobSliceModel) MarshalCBOR ¶
func (t *BlobSliceModel) MarshalCBOR(w io.Writer) error
func (*BlobSliceModel) MarshalDagJSON ¶
func (t *BlobSliceModel) MarshalDagJSON(w io.Writer) error
func (*BlobSliceModel) UnmarshalCBOR ¶
func (t *BlobSliceModel) UnmarshalCBOR(r io.Reader) (err error)
func (*BlobSliceModel) UnmarshalDagJSON ¶
func (t *BlobSliceModel) UnmarshalDagJSON(r io.Reader) (err error)
type RangeModel ¶
RangeModel is a start and end byte offset for a slice in a blob (inclusive)
func (*RangeModel) MarshalCBOR ¶
func (t *RangeModel) MarshalCBOR(w io.Writer) error
func (*RangeModel) MarshalDagJSON ¶
func (t *RangeModel) MarshalDagJSON(w io.Writer) error
func (*RangeModel) UnmarshalCBOR ¶
func (t *RangeModel) UnmarshalCBOR(r io.Reader) (err error)
func (*RangeModel) UnmarshalDagJSON ¶
func (t *RangeModel) UnmarshalDagJSON(r io.Reader) (err error)
type ShardedDagIndexModel ¶
type ShardedDagIndexModel struct {
DagO_1 *ShardedDagIndexModel_0_1 `cborgen:"index/sharded/dag@0.1,omitempty" dagjsongen:"index/sharded/dag@0.1,omitempty"`
}
ShardedDagIndexModel is the golang structure for encoding sharded DAG index header blocks
func (*ShardedDagIndexModel) MarshalCBOR ¶
func (t *ShardedDagIndexModel) MarshalCBOR(w io.Writer) error
func (*ShardedDagIndexModel) MarshalDagJSON ¶
func (t *ShardedDagIndexModel) MarshalDagJSON(w io.Writer) error
func (*ShardedDagIndexModel) UnmarshalCBOR ¶
func (t *ShardedDagIndexModel) UnmarshalCBOR(r io.Reader) (err error)
func (*ShardedDagIndexModel) UnmarshalDagJSON ¶
func (t *ShardedDagIndexModel) UnmarshalDagJSON(r io.Reader) (err error)
type ShardedDagIndexModel_0_1 ¶
ShardedDagIndexModel_0_1 describes the 0.1 version of ShardedDagIndex
func (*ShardedDagIndexModel_0_1) MarshalCBOR ¶
func (t *ShardedDagIndexModel_0_1) MarshalCBOR(w io.Writer) error
func (*ShardedDagIndexModel_0_1) MarshalDagJSON ¶
func (t *ShardedDagIndexModel_0_1) MarshalDagJSON(w io.Writer) error
func (*ShardedDagIndexModel_0_1) UnmarshalCBOR ¶
func (t *ShardedDagIndexModel_0_1) UnmarshalCBOR(r io.Reader) (err error)
func (*ShardedDagIndexModel_0_1) UnmarshalDagJSON ¶
func (t *ShardedDagIndexModel_0_1) UnmarshalDagJSON(r io.Reader) (err error)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.