Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CapabilityRequestModel ¶
func (*CapabilityRequestModel) MarshalCBOR ¶
func (t *CapabilityRequestModel) MarshalCBOR(w io.Writer) error
func (*CapabilityRequestModel) MarshalDagJSON ¶
func (t *CapabilityRequestModel) MarshalDagJSON(w io.Writer) error
func (*CapabilityRequestModel) UnmarshalCBOR ¶
func (t *CapabilityRequestModel) UnmarshalCBOR(r io.Reader) (err error)
func (*CapabilityRequestModel) UnmarshalDagJSON ¶
func (t *CapabilityRequestModel) UnmarshalDagJSON(r io.Reader) (err error)
type ClaimOKModel ¶
type ClaimOKModel struct {
// Delegations is a list of the CIDs of delegations granted for the request.
Delegations []cid.Cid `cborgen:"delegations" dagjsongen:"delegations"`
}
func (*ClaimOKModel) MarshalCBOR ¶
func (t *ClaimOKModel) MarshalCBOR(w io.Writer) error
func (*ClaimOKModel) MarshalDagJSON ¶
func (t *ClaimOKModel) MarshalDagJSON(w io.Writer) error
func (*ClaimOKModel) UnmarshalCBOR ¶
func (t *ClaimOKModel) UnmarshalCBOR(r io.Reader) (err error)
func (*ClaimOKModel) UnmarshalDagJSON ¶
func (t *ClaimOKModel) UnmarshalDagJSON(r io.Reader) (err error)
type ConfirmArgumentsModel ¶
type ConfirmArgumentsModel struct {
// Link to the `/access/request` this invocation is confirming.
Cause cid.Cid `cborgen:"cause" dagjsongen:"cause"`
Issuer did.DID `cborgen:"iss" dagjsongen:"iss"`
Audience did.DID `cborgen:"aud" dagjsongen:"aud"`
Attenuations []CapabilityRequestModel `cborgen:"att" dagjsongen:"att"`
}
func (*ConfirmArgumentsModel) MarshalCBOR ¶
func (t *ConfirmArgumentsModel) MarshalCBOR(w io.Writer) error
func (*ConfirmArgumentsModel) MarshalDagJSON ¶
func (t *ConfirmArgumentsModel) MarshalDagJSON(w io.Writer) error
func (*ConfirmArgumentsModel) UnmarshalCBOR ¶
func (t *ConfirmArgumentsModel) UnmarshalCBOR(r io.Reader) (err error)
func (*ConfirmArgumentsModel) UnmarshalDagJSON ¶
func (t *ConfirmArgumentsModel) UnmarshalDagJSON(r io.Reader) (err error)
type ConfirmOKModel ¶
type ConfirmOKModel = ClaimOKModel
type DelegateArgumentsModel ¶
type DelegateArgumentsModel struct {
// The delegations to store.
Delegations []cid.Cid `cborgen:"delegations" dagjsongen:"delegations"`
}
func (*DelegateArgumentsModel) MarshalCBOR ¶
func (t *DelegateArgumentsModel) MarshalCBOR(w io.Writer) error
func (*DelegateArgumentsModel) MarshalDagJSON ¶
func (t *DelegateArgumentsModel) MarshalDagJSON(w io.Writer) error
func (*DelegateArgumentsModel) UnmarshalCBOR ¶
func (t *DelegateArgumentsModel) UnmarshalCBOR(r io.Reader) (err error)
func (*DelegateArgumentsModel) UnmarshalDagJSON ¶
func (t *DelegateArgumentsModel) UnmarshalDagJSON(r io.Reader) (err error)
type RequestArgumentsModel ¶
type RequestArgumentsModel struct {
// DID of the Account authorization is requested from.
Issuer did.DID `cborgen:"iss" dagjsongen:"iss"`
// Capabilities agent wishes to be granted.
Attenuations []CapabilityRequestModel `cborgen:"att" dagjsongen:"att"`
}
func (*RequestArgumentsModel) MarshalCBOR ¶
func (t *RequestArgumentsModel) MarshalCBOR(w io.Writer) error
func (*RequestArgumentsModel) MarshalDagJSON ¶
func (t *RequestArgumentsModel) MarshalDagJSON(w io.Writer) error
func (*RequestArgumentsModel) UnmarshalCBOR ¶
func (t *RequestArgumentsModel) UnmarshalCBOR(r io.Reader) (err error)
func (*RequestArgumentsModel) UnmarshalDagJSON ¶
func (t *RequestArgumentsModel) UnmarshalDagJSON(r io.Reader) (err error)
type RequestOKModel ¶
type RequestOKModel struct {
// Request is a link to the access request invocation.
Request cid.Cid `cborgen:"req" dagjsongen:"req"`
// Confirm is the task that will confirm the access request.
Confirm promise.AwaitOK `cborgen:"confirm" dagjsongen:"confirm"`
// Expiration is the time at which the confirmation will expire.
Expiration int64 `cborgen:"exp" dagjsongen:"exp"`
}
func (*RequestOKModel) MarshalCBOR ¶
func (t *RequestOKModel) MarshalCBOR(w io.Writer) error
func (*RequestOKModel) MarshalDagJSON ¶
func (t *RequestOKModel) MarshalDagJSON(w io.Writer) error
func (*RequestOKModel) UnmarshalCBOR ¶
func (t *RequestOKModel) UnmarshalCBOR(r io.Reader) (err error)
func (*RequestOKModel) UnmarshalDagJSON ¶
func (t *RequestOKModel) UnmarshalDagJSON(r io.Reader) (err error)
Click to show internal directories.
Click to hide internal directories.