Documentation
¶
Index ¶
Constants ¶
const EqualsCommand = "/assert/equals"
const IndexCommand = "/assert/index"
const LocationCommand = "/assert/location"
Variables ¶
var Equals, _ = bindcap.New[*EqualsArguments](EqualsCommand)
Equals claims data is referred to by another CID e.g CAR CID & Piece CID
var Index, _ = bindcap.New[*IndexArguments](IndexCommand)
Index claims that a content graph can be found in blob(s) that are identified and indexed in the given index CID.
var Location, _ = bindcap.New[*LocationArguments](LocationCommand)
Functions ¶
This section is empty.
Types ¶
type EqualsArguments ¶
type EqualsArguments = adm.EqualsArgumentsModel
type IndexArguments ¶
type IndexArguments = adm.IndexArgumentsModel
type LocationArguments ¶
type LocationArguments = adm.LocationArgumentsModel
type LocationOK ¶
type Range ¶
type Range = adm.RangeModel
Click to show internal directories.
Click to hide internal directories.